@@ -6,12 +6,11 @@
 **  as the user if it matches.
 */
 
-#include "config.h"
-#include "clibrary.h"
+#include "portable/system.h"
 
-#include "inn/messages.h"
 #include "inn/libinn.h"
-#include "libauth.h"
+#include "inn/messages.h"
+#include "libinnauth.h"
 
 int
 main(int argc, char *argv[])
