@@ -524,7 +524,7 @@ ProcessHeaders(bool AddOrg, bool AddSender, struct passwd *pwp)
 
     /* Set Message-ID */
     if (HDR(_messageid) == NULL) {
-        if ((p = GenerateMessageID(innconf->domain)) == NULL)
+        if ((p = GenerateMessageID(NULL)) == NULL)
             die("cannot generate Message-ID header field body");
         HDR(_messageid) = xstrdup(p);
     } else if ((p = strchr(HDR(_messageid), '@')) == NULL
@@ -821,7 +821,7 @@ main(int ac, char *av[])
      *
      * The flags are compatible with the original inews (C News) and the
      * improved inews-xt from Olaf Titz.
-     * Also keep compatibility with tinews (shipped with tin). */
+     * Also keep compatibility with tinews.pl (shipped with tin). */
     while ((i = getopt(ac, av,
                        "a:Ac:d:De:Ef:F:hHi:ILm:n:No:Op:Pr:Rs:St:vVw:Wx:XY"))
            != EOF) {
@@ -845,7 +845,7 @@ main(int ac, char *av[])
         case 'I': /* Don't add Injection-Date. */
         case 'L': /* Don't add Cancel-Key. */
         case 'v': /* Verbose mode. */
-            /* Ignore tinews options. */
+            /* Ignore tinews.pl options. */
             break;
         case 'E':
             DiscardEmpty = true;
@@ -874,8 +874,8 @@ main(int ac, char *av[])
         case 'p':
             port = atoi(optarg);
             break;
+            /* clang-format off */
         /* Header fields that can be specified on the command line. */
-        /* clang-format off */
         case 'a':   HDR(_approved) = optarg;       break;
         case 'c':   HDR(_control) = optarg;        break;
         case 'd':   HDR(_distribution) = optarg;   break;
@@ -888,8 +888,8 @@ main(int ac, char *av[])
         case 'F':   HDR(_references) = optarg;     break;
         case 'o':   HDR(_organization) = optarg;   break;
         case 'w':   HDR(_followupto) = optarg;     break;
+            /* clang-format on */
         }
-        /* clang-format on */
     }
     ac -= optind;
     av += optind;
