@@ -365,7 +365,7 @@ RCrejectwritedone(CHANNEL *cp)
 {
     switch (cp->State) {
     default:
-        syslog(L_ERROR, "%s internal RCrejectwritedone state %d", CHANname(cp),
+        syslog(L_ERROR, "%s internal RCrejectwritedone state %u", CHANname(cp),
                cp->State);
         break;
     case CSwritegoodbye:
@@ -405,7 +405,7 @@ RChandoff(int fd, HANDOFF h)
         syslog(L_ERROR, "%s cant nonblock %d in RChandoff %m", LogName, fd);
     switch (h) {
     default:
-        syslog(L_ERROR, "%s internal RChandoff %d type %d", LogName, fd, h);
+        syslog(L_ERROR, "%s internal RChandoff %d type %u", LogName, fd, h);
         goto fallthroughHOnnrpd;
     case HOnnrpd:
     fallthroughHOnnrpd:
@@ -482,6 +482,15 @@ RCreader(CHANNEL *cp)
         return;
     }
 
+    if (!isvalidfd(fd)) {
+        syslog(L_ERROR,
+               "%s cant accept RCreader: file descriptor %d too high (see "
+               "rlimitnofile in inn.conf)",
+               LogName, fd);
+        close(fd);
+        return;
+    }
+
     /* If RemoteTimer is not zero, then check the limits on incoming
        connections on a total and per host basis.
 
@@ -1111,9 +1120,12 @@ RCreadfile(REMOTEHOST_DATA **data, REMOTEHOST **list, int *count,
             if ((word = RCreaddata(&linecount, F, &toolong)) == NULL) {
                 break;
             }
-            if (!strcmp(word, "true"))
+            if (strcasecmp(word, "true") == 0 || strcasecmp(word, "yes") == 0
+                || strcasecmp(word, "on") == 0)
                 flag = true;
-            else if (!strcmp(word, "false"))
+            else if (strcasecmp(word, "false") == 0
+                     || strcasecmp(word, "no") == 0
+                     || strcasecmp(word, "off") == 0)
                 flag = false;
             else {
                 syslog(L_ERROR, MUST_BE_BOOL, LogName, filename, linecount);
@@ -1141,9 +1153,12 @@ RCreadfile(REMOTEHOST_DATA **data, REMOTEHOST **list, int *count,
             if ((word = RCreaddata(&linecount, F, &toolong)) == NULL) {
                 break;
             }
-            if (!strcmp(word, "true"))
+            if (strcasecmp(word, "true") == 0 || strcasecmp(word, "yes") == 0
+                || strcasecmp(word, "on") == 0)
                 flag = true;
-            else if (!strcmp(word, "false"))
+            else if (strcasecmp(word, "false") == 0
+                     || strcasecmp(word, "no") == 0
+                     || strcasecmp(word, "off") == 0)
                 flag = false;
             else {
                 syslog(L_ERROR, MUST_BE_BOOL, LogName, filename, linecount);
@@ -1171,9 +1186,12 @@ RCreadfile(REMOTEHOST_DATA **data, REMOTEHOST **list, int *count,
             if ((word = RCreaddata(&linecount, F, &toolong)) == NULL) {
                 break;
             }
-            if (!strcmp(word, "true"))
+            if (strcasecmp(word, "true") == 0 || strcasecmp(word, "yes") == 0
+                || strcasecmp(word, "on") == 0)
                 flag = true;
-            else if (!strcmp(word, "false"))
+            else if (strcasecmp(word, "false") == 0
+                     || strcasecmp(word, "no") == 0
+                     || strcasecmp(word, "off") == 0)
                 flag = false;
             else {
                 syslog(L_ERROR, MUST_BE_BOOL, LogName, filename, linecount);
@@ -1201,9 +1219,12 @@ RCreadfile(REMOTEHOST_DATA **data, REMOTEHOST **list, int *count,
             if ((word = RCreaddata(&linecount, F, &toolong)) == NULL) {
                 break;
             }
-            if (!strcmp(word, "true"))
+            if (strcasecmp(word, "true") == 0 || strcasecmp(word, "yes") == 0
+                || strcasecmp(word, "on") == 0)
                 flag = true;
-            else if (!strcmp(word, "false"))
+            else if (strcasecmp(word, "false") == 0
+                     || strcasecmp(word, "no") == 0
+                     || strcasecmp(word, "off") == 0)
                 flag = false;
             else {
                 syslog(L_ERROR, MUST_BE_BOOL, LogName, filename, linecount);
@@ -1231,9 +1252,12 @@ RCreadfile(REMOTEHOST_DATA **data, REMOTEHOST **list, int *count,
             if ((word = RCreaddata(&linecount, F, &toolong)) == NULL) {
                 break;
             }
-            if (!strcmp(word, "true"))
+            if (strcasecmp(word, "true") == 0 || strcasecmp(word, "yes") == 0
+                || strcasecmp(word, "on") == 0)
                 flag = true;
-            else if (!strcmp(word, "false"))
+            else if (strcasecmp(word, "false") == 0
+                     || strcasecmp(word, "no") == 0
+                     || strcasecmp(word, "off") == 0)
                 flag = false;
             else {
                 syslog(L_ERROR, MUST_BE_BOOL, LogName, filename, linecount);
@@ -1261,9 +1285,12 @@ RCreadfile(REMOTEHOST_DATA **data, REMOTEHOST **list, int *count,
             if ((word = RCreaddata(&linecount, F, &toolong)) == NULL) {
                 break;
             }
-            if (!strcmp(word, "true"))
+            if (strcasecmp(word, "true") == 0 || strcasecmp(word, "yes") == 0
+                || strcasecmp(word, "on") == 0)
                 flag = true;
-            else if (!strcmp(word, "false"))
+            else if (strcasecmp(word, "false") == 0
+                     || strcasecmp(word, "no") == 0
+                     || strcasecmp(word, "off") == 0)
                 flag = false;
             else {
                 syslog(L_ERROR, MUST_BE_BOOL, LogName, filename, linecount);
@@ -1766,6 +1793,11 @@ RCsetup(void)
             if (sd_is_socket(i, AF_UNSPEC, SOCK_STREAM, 1) <= 0)
                 die("SERVER can't use socket-activated non-AF_INET socket %u",
                     i);
+            if (!isvalidfd(i))
+                die("SERVER can't use socket-activated non-AF_INET socket: "
+                    "file descriptor %u too high (see rlimitnofile in "
+                    "inn.conf)",
+                    i);
             rc = CHANcreate(i, CTremconn, CSwaiting, RCreader, RCwritedone);
             notice("%s rcsetup %s", LogName, CHANname(rc));
             RCHANadd(rc);
@@ -1825,6 +1857,12 @@ RCsetup(void)
     for (i = 0; i < count; i++) {
         if (fds[i] < 0)
             continue;
+        if (!isvalidfd(fds[i])) {
+            syswarn("SERVER cant listen to socket: file descriptor %d too "
+                    "high (see rlimitnofile in inn.conf)",
+                    fds[i]);
+            continue;
+        }
         if (listen(fds[i], innconf->maxlisten) < 0) {
             if (i != 0 && errno == EADDRINUSE)
                 continue;
