@@ -210,6 +210,7 @@ static const struct config config_table[] = {
     {K(nfswriter),                  BOOL(false)       },
     {K(nnrpdcheckart),              BOOL(true)        },
     {K(overcachesize),              UNUMBER(128)      },
+    {K(ovflushcount),               UNUMBER(50)       },
     {K(ovgrouppat),                 STRING(NULL)      },
     {K(storeonxref),                BOOL(true)        },
     {K(tradindexedmmap),            BOOL(true)        },
@@ -443,12 +444,24 @@ innconf_validate(struct config_group *group)
     unsigned int i;
     char *fqdn;
 
+    /* Checks to ensure valid Message-IDs will be generated. */
     fqdn = inn_getfqdn(innconf->domain);
     if (fqdn == NULL) {
         warn("hostname does not resolve or domain not set in inn.conf");
         okay = false;
     }
+    if (innconf->domain != NULL && !IsValidDomain(innconf->domain)) {
+        warn("domain in inn.conf contains invalid characters not suitable for "
+             "Message-IDs");
+        okay = false;
+    }
+    if (innconf->domain == NULL && !IsValidDomain(fqdn)) {
+        warn("the FQDN of the server contains invalid characters not suitable "
+             "for Message-IDs");
+        okay = false;
+    }
     free(fqdn);
+
     if (innconf->mta == NULL) {
         warn("must set mta in inn.conf");
         okay = false;
@@ -554,6 +567,33 @@ innconf_validate(struct config_group *group)
         }
     }
 
+    /* Do not accept header field names beginning with a dot (extra complexity
+     * not handled in the code for correctly dot-stuffing them). */
+    if (innconf->extraoverviewadvertised->strings != NULL) {
+        for (i = 0; i < innconf->extraoverviewadvertised->count; i++) {
+            if (innconf->extraoverviewadvertised->strings[i] != NULL
+                && (*innconf->extraoverviewadvertised->strings[i] == '.')) {
+                config_error_param(group, "extraoverviewadvertised",
+                                   "Header field names beginning with a dot "
+                                   "not allowed in overview data");
+                okay = false;
+                break;
+            }
+        }
+    }
+    if (innconf->extraoverviewhidden->strings != NULL) {
+        for (i = 0; i < innconf->extraoverviewhidden->count; i++) {
+            if (innconf->extraoverviewhidden->strings[i] != NULL
+                && (*innconf->extraoverviewhidden->strings[i] == '.')) {
+                config_error_param(group, "extraoverviewhidden",
+                                   "Header field names beginning with a dot "
+                                   "not allowed in overview data");
+                okay = false;
+                break;
+            }
+        }
+    }
+
     return okay;
 }
 
@@ -883,7 +923,7 @@ innconf_compare(struct innconf *conf1, struct innconf *conf2)
             }
             break;
         default:
-            die("internal error: invalid type in row %d of config table", i);
+            die("internal error: invalid type in row %u of config table", i);
         }
     return okay;
 }
