@@ -4,11 +4,6 @@
 
 #include "portable/system.h"
 
-/* Needed on AIX 4.1 to get fd_set and friends. */
-#ifdef HAVE_SYS_SELECT_H
-#    include <sys/select.h>
-#endif
-
 #include "inn/innconf.h"
 #include "nnrpd.h"
 #include "tls.h"
@@ -595,7 +590,7 @@ CMDstarttls(int ac UNUSED, char *av[] UNUSED)
         free(GRPcur);
         GRPcur = NULL;
         if (ARTcount) {
-            syslog(L_NOTICE, "%s exit for STARTTLS articles %ld groups %ld",
+            syslog(L_NOTICE, "%s exit for STARTTLS articles %lu groups %ld",
                    Client.host, ARTcount, GRPcount);
         }
         GRPcount = 0;
