@@ -71,7 +71,7 @@ my %timer_names = (
     overv    => 'overview write',
     perl     => 'perl filter',
     python   => 'python filter',
-    datamove => 'data move'
+    datamove => 'data move',
 );
 
 my %innfeed_timer_names = (
@@ -438,8 +438,7 @@ sub collect($$$$$$) {
         # 437 No colon-space in "xxxx" header field
         if ($left
             =~ /(\S+) <[^>]+> (?:437|439) No colon-space in \"[^\"]+\" header field/o
-          )
-        {
+        ) {
             my $server = $1;
             $server = lc $server unless $CASE_SENSITIVE;
             $inn_badart{$server}++;
@@ -450,8 +449,7 @@ sub collect($$$$$$) {
         # 437 Article injected or posted in the future -- "xxxxx"
         if ($left
             =~ /(\S+) <[^>]+> (?:437|439) Article injected or posted in the future -- \"[^\"]+\"/o
-          )
-        {
+        ) {
             my $server = $1;
             $server = lc $server unless $CASE_SENSITIVE;
             $innd_posted_future{$server}++;
@@ -502,7 +500,17 @@ sub collect($$$$$$) {
             return 1 if $left =~ /^SERVER Python filtering disabled$/o;
             # SERVER cancelled +id
             return 1 if $left =~ /^SERVER cancelled /o;
+            # SERVER trace (innd|nnrpd) (on|off)
+            return 1 if $left =~ /^SERVER trace \w+ (on|off)$/o;
+            # SERVER changed -c 42
+            return 1 if $left =~ /^SERVER changed -\w \d+$/o;
+            # SERVER changed -T from 12 to 42
+            return 1 if $left =~ /^SERVER changed -\w from \d+ to \d+$/o;
         }
+        # channel tracing
+        return 1 if $left =~ /^\S+:\d+(:\S+)? trace /o;
+        # ctlinnd hangup
+        return 1 if $left =~ /^\S+:\d+(:\S+)? hangup$/o;
         # Python filter
         return 1 if $left =~ /^defined python methods$/o;
         return 1 if $left =~ /^reloading pyfilter$/o;
@@ -638,11 +646,10 @@ sub collect($$$$$$) {
         # useless to take into account a line corresponding to a closed status.
         if ($left
             =~ /(\S+:\d+) (checkpoint|closed) seconds (\d+) accepted (\d+) refused (\d+) rejected (\d+) duplicate (\d+) accepted size (\d+) duplicate size (\d+)(?: rejected size (\d+))?$/o
-          )
-        {
+        ) {
             my (
                 $server, $status, $seconds, $accepted, $refused, $rejected,
-                $duplicate, $accptsize, $dupsize, $rjctsize
+                $duplicate, $accptsize, $dupsize, $rjctsize,
             ) = ($1, $2, $3, $4, $5, $6, $7, $8, $9, $10);
             $server = lc $server unless $CASE_SENSITIVE;
 
@@ -712,8 +719,7 @@ sub collect($$$$$$) {
                        time\s(\d+)\s+                  # time
                        ((?:\S+\s\d+\(\d+\)\s*)+)       # timer values
                        $/ox
-          )
-        {
+        ) {
             $innd_time_times += $1;
             my $timers = $2;
 
@@ -750,8 +756,7 @@ sub collect($$$$$$) {
                    \ (\d+)\s+missed               # missed
                    \ (\d+)\s+dne                  # dne
                    $/ox
-          )
-        {
+        ) {
             $innd_his{'Positive hits'} += $1;
             $innd_his{'Negative hits'} += $2;
             $innd_his{'Cache misses'} += $3;
@@ -965,11 +970,10 @@ sub collect($$$$$$) {
         # checkpoint (real) (new format)
         if ($left
             =~ /(\S+) checkpoint seconds (\d+) offered (\d+) accepted (\d+) refused (\d+) rejected (\d+) missing (\d+) accsize (\d+) rejsize (\d+) spooled (\d+)/o
-          )
-        {
+        ) {
             my (
                 $server, $seconds, $offered, $accepted, $refused, $rejected,
-                $missing, $accepted_size, $rejected_size, $spooled
+                $missing, $accepted_size, $rejected_size, $spooled,
             ) = ($1, $2, $3, $4, $5, $6, $7, $8, $9, $10);
             $server = lc $server unless $CASE_SENSITIVE;
             $innfeed_seconds{$server} += $seconds;
@@ -984,11 +988,10 @@ sub collect($$$$$$) {
             return 1;
         } elsif ($left
             =~ /(\S+) checkpoint seconds (\d+) offered (\d+) accepted (\d+) refused (\d+) rejected (\d+) missing (\d+) spooled (\d+)/o
-          )
-        {
+        ) {
             my (
                 $server, $seconds, $offered, $accepted, $refused, $rejected,
-                $missing, $spooled
+                $missing, $spooled,
             ) = ($1, $2, $3, $4, $5, $6, $7, $8);
             $server = lc $server unless $CASE_SENSITIVE;
             $innfeed_seconds{$server} += $seconds;
@@ -1030,8 +1033,7 @@ sub collect($$$$$$) {
                        time\s(\d+)\s+                  # time
                        ((?:\S+\s\d+\(\d+\)\s*)+)       # timer values
                        $/ox
-          )
-        {
+        ) {
             $innfeed_time_times += $1;
             my $timers = $2;
 
@@ -1162,11 +1164,10 @@ sub collect($$$$$$) {
         # stats
         if ($left
             =~ /(\S+) stats offered (\d+) accepted (\d+) refused (\d+) rejected (\d+) accsize (\d+) rejsize (\d+)$/o
-          )
-        {
+        ) {
             my (
                 $server, $offered, $accepted, $refused, $rejected, $accbytes,
-                $rejbytes
+                $rejbytes,
             ) = ($1, $2, $3, $4, $5, $6, $7);
             $server = lc $server unless $CASE_SENSITIVE;
             $innxbatch_offered{$server} += $offered;
@@ -1193,8 +1194,7 @@ sub collect($$$$$$) {
         # 437 Duplicate article
         if ($left
             =~ /(\S+) rejected [^\s]+ \(.*?\) (?:437|439) Duplicate article$/o
-          )
-        {
+        ) {
             my $server = $1;
             $server = lc $server unless $CASE_SENSITIVE;
             $innxmit_badart{$server}++;
@@ -1204,8 +1204,7 @@ sub collect($$$$$$) {
         # 437 Unapproved for
         if ($left
             =~ /(\S+) rejected [^\s]+ \(.*\) (?:437|439) Unapproved for \"(.*?)\"$/o
-          )
-        {
+        ) {
             my ($server, $group) = ($1, $2);
             $server = lc $server unless $CASE_SENSITIVE;
             $innxmit_badart{$server}++;
@@ -1216,8 +1215,7 @@ sub collect($$$$$$) {
         # 437 Too old -- ...
         if ($left
             =~ /(\S+) rejected [^\s]+ \(.*\) (?:437|439) Too old -- \".*?\"$/o
-          )
-        {
+        ) {
             my $server = $1;
             $server = lc $server unless $CASE_SENSITIVE;
             $innxmit_badart{$server}++;
@@ -1227,8 +1225,7 @@ sub collect($$$$$$) {
         # 437 Unwanted site ... in path
         if ($left
             =~ /(\S+) rejected [^\s]+ \(.*?\) (?:437|439) Unwanted site (\S+) in path$/o
-          )
-        {
+        ) {
             my ($server, $site) = ($1, $2);
             $server = lc $server unless $CASE_SENSITIVE;
             $innxmit_badart{$server}++;
@@ -1239,8 +1236,7 @@ sub collect($$$$$$) {
         # 437 Unwanted newsgroup "..."
         if ($left
             =~ /(\S+) rejected [^\s]+ \(.*?\) (?:437|439) Unwanted newsgroup \"(\S+)\"$/o
-          )
-        {
+        ) {
             my ($server, $group) = ($1, $2);
             $server = lc $server unless $CASE_SENSITIVE;
             $innxmit_badart{$server}++;
@@ -1251,8 +1247,7 @@ sub collect($$$$$$) {
         # 437 Unwanted distribution "..."
         if ($left
             =~ /(\S+) rejected [^\s]+ \(.*?\) (?:437|439) Unwanted distribution \"(\S+)\"$/o
-          )
-        {
+        ) {
             my ($server, $dist) = ($1, $2);
             $server = lc $server unless $CASE_SENSITIVE;
             $innxmit_badart{$server}++;
@@ -1264,8 +1259,7 @@ sub collect($$$$$$) {
         # 437 Unwanted distribution "..."
         if ($left
             =~ /^(\S+) rejected .* (?:437|439) Unwanted distribution \"(\S+)\"$/o
-          )
-        {
+        ) {
             my ($server, $dist) = ($1, $2);
             $server = lc $server unless $CASE_SENSITIVE;
             $innxmit_badart{$server}++;
@@ -1284,8 +1278,7 @@ sub collect($$$$$$) {
         # 437 Newsgroup name illegal -- "xxx"
         if ($left
             =~ /(\S+) rejected .* (?:437|439) Newsgroup name illegal -- "[^\"]*"$/
-          )
-        {
+        ) {
             my $server = $1;
             $server = lc $server unless $CASE_SENSITIVE;
             $innxmit_others{$server}++;
@@ -1319,11 +1312,10 @@ sub collect($$$$$$) {
         # stats (new format)
         if ($left
             =~ /(\S+) stats offered (\d+) accepted (\d+) refused (\d+) rejected (\d+) missing (\d+) accsize (\d+) rejsize (\d+)$/o
-          )
-        {
+        ) {
             my (
                 $server, $offered, $accepted, $refused, $rejected, $missing,
-                $accbytes, $rejbytes
+                $accbytes, $rejbytes,
             ) = ($1, $2, $3, $4, $5, $6, $7, $8);
             $server = lc $server unless $CASE_SENSITIVE;
             $innxmit_offered{$server} += $offered;
@@ -1342,8 +1334,7 @@ sub collect($$$$$$) {
         # stats
         if ($left
             =~ /(\S+) stats offered (\d+) accepted (\d+) refused (\d+) rejected (\d+)$/o
-          )
-        {
+        ) {
             my ($server, $offered, $accepted, $refused, $rejected)
               = ($1, $2, $3, $4, $5);
             $server = lc $server unless $CASE_SENSITIVE;
@@ -1544,8 +1535,7 @@ sub collect($$$$$$) {
         # article .. 400 No space left on device writing article file
         if ($left
             =~ /(\S+) .* 400 No space left on device writing article file -- throttling$/o
-          )
-        {
+        ) {
             my $server = $1;
             $server = lc $server unless $CASE_SENSITIVE;
             $nntplink_nospace{$server}++;
@@ -1554,8 +1544,7 @@ sub collect($$$$$$) {
         # stats
         if ($left
             =~ /(\S+) stats (\d+) offered (\d+) accepted (\d+) rejected (\d+) failed (\d+) connects$/o
-          )
-        {
+        ) {
             my ($server, $offered, $accepted, $rejected, $failed, $connects)
               = ($1, $2, $3, $4, $5, $6);
             $server = lc $server unless $CASE_SENSITIVE;
@@ -1668,9 +1657,15 @@ sub collect($$$$$$) {
         return 1
           if $left
           =~ /^python: dynamic authorization access type is not known: /o;
+        # during daily expiration
+        return 1 if $left =~ /^\S+ rejected Expiring process \d+$/o;
+        # during ovsqlite-util
+        return 1 if $left =~ /^\S+ rejected ovsqlite-util fixes$/o;
         # during scanlogs
         return 1 if $left =~ /^\S+ rejected Flushing log and syslog files$/o;
         return 1 if $left =~ /^\S+ rejected Snapshot log and syslog files$/o;
+        # during scanspool
+        return 1 if $left =~ /^\S+ rejected running scanspool$/o;
         # other logs that should not be reported as errors
         return 1 if $left =~ /^\S+ auth also-log: /o;
         return 1 if $left =~ /^\S+ res also-log: /o;
@@ -1760,8 +1755,7 @@ sub collect($$$$$$) {
             ($left =~ /\S+ user (.+)$/o)
             && ($left
                 !~ /\S+ times user .+ system \S+ idle \S+ elapsed \S+$/o)
-          )
-        {
+        ) {
             my $user = $1;
             $nnrpd_auth{$user}++;
             return 1;
@@ -1781,8 +1775,7 @@ sub collect($$$$$$) {
         # exit (also called when using STARTTLS)
         if ($left
             =~ /(\S+) (?:exit|exit for STARTTLS|exit for AUTHINFO SASL) articles (\d+) groups (\d+)$/o
-          )
-        {
+        ) {
             my ($cust, $articles, $groups) = ($1, $2, $3);
             $cust = lc $cust unless $CASE_SENSITIVE;
             my $dom = &host2dom($cust);
@@ -1797,8 +1790,7 @@ sub collect($$$$$$) {
         # times
         if ($left
             =~ /(\S+) times user (.+) system (\S+) idle (\S+) elapsed (\S+)$/o
-          )
-        {
+        ) {
             my ($cust, $user, $system, $idle, $elapsed) = ($1, $2, $3, $4, $5);
             $cust = lc $cust unless $CASE_SENSITIVE;
             my $dom = &host2dom($cust);
@@ -1909,8 +1901,7 @@ sub collect($$$$$$) {
                        time\s(\d+)\s+                  # time
                        ((?:\S+\s\d+\(\d+\)\s*)+)       # timer values
                        $/ox
-          )
-        {
+        ) {
             $nnrpd_time_times += $1;
             my $timers = $2;
 
@@ -2026,8 +2017,7 @@ sub collect($$$$$$) {
         # rejected 437 Article injected or posted in the future
         if ($left
             =~ /rejected (?:437|439) Article injected or posted in the future -- \"(.*)\"$/o
-          )
-        {
+        ) {
             $rnews_bogus_date{"(future) $1"}++;
             return 1;
         }
@@ -2054,8 +2044,7 @@ sub collect($$$$$$) {
         # rejected 437 No colon-space ...
         if ($left
             =~ /rejected (?:437|439) No colon-space in \"(.*)\" header field$/o
-          )
-        {
+        ) {
             $rnews_no_colon_space++;
             return 1;
         }
@@ -2209,8 +2198,7 @@ sub collect($$$$$$) {
                   \s*(.*)               # 1 if message approved
                                         # and first logged in the file
                   /x
-          )
-        {
+        ) {
             if ($1 eq 'newgroup') {
                 $controlchan_new{$3}++;
             } elsif ($1 eq 'rmgroup') {
@@ -2243,8 +2231,7 @@ sub collect($$$$$$) {
                     \ used:\ ([\d.]+)\ Mbytes\ \(\s*[\d.]+%\)
                     \s+(\d+)\ cycles\s*
                  $|ox
-          )
-        {
+        ) {
             my ($class, $buffer, $size, $used, $cycles) = ($1, $3, $4, $5, $6);
             my ($h, $m, $s) = $hour =~ m/^(\d+):(\d+):(\d+)$/;
             my $time = $h * 3600 + $m * 60 + $s;
@@ -2456,7 +2443,7 @@ sub adjust($$) {
             my ($r, $h) = $day =~ /^(.*) (\d+)$/;
             my $d = index(
                 "JanFebMarAprMayJunJulAugSepOctNovDec",
-                substr($r, 0, 3)
+                substr($r, 0, 3),
             ) / 3 * 31 + substr($r, 4, 2);
             $prev_h = $h if ($prev_h == -1);
             if ($prev_d == -1) {
