@@ -1004,8 +1004,8 @@ cnfs_mapcntl(void *p, size_t length, int flags)
 {
     char *start, *end;
 
-    start = (char *) ((size_t) p & ~(size_t) (pagesize - 1));
-    end = (char *) ((size_t) ((char *) p + length + pagesize)
+    start = (char *) ((uintptr_t) p & ~(size_t) (pagesize - 1));
+    end = (char *) (((uintptr_t) p + length + pagesize)
                     & ~(size_t) (pagesize - 1));
     if (flags == MS_INVALIDATE) {
         msync(start, end - start, flags);
