@@ -1234,6 +1234,9 @@ do_add_article(client_t *client)
     if (!finish_request(client))
         fail(response_bad_request);
 
+    if (overview_len > MAX_OVDATA_SIZE)
+        fail(response_corrupted);
+
     begin_transaction();
 
     stmt = sql_main.lookup_groupinfo;
@@ -1584,7 +1587,7 @@ do_search_group(client_t *client)
 
             overview = sqlite3_column_blob(stmt, 4);
             size = sqlite3_column_bytes(stmt, 4);
-            if (!overview || size > 100000)
+            if (!overview || size > MAX_OVDATA_SIZE)
                 goto corrupted;
             overview_len = size;
 #    ifdef HAVE_ZLIB
@@ -1605,7 +1608,7 @@ do_search_group(client_t *client)
                 inflation.avail_in = overview_len;
 
                 raw_len = unpack_length(&inflation);
-                if (raw_len > 100000)
+                if (raw_len > MAX_OVDATA_SIZE)
                     goto corrupted;
                 if (raw_len > 0) {
                     buffer_resize(flate, raw_len);
